@@ -1,4 +1,6 @@
 from typing import List, Callable
+
+from datetime import datetime
 import os
 import asyncpg
 
@@ -29,6 +31,17 @@ session = {}
 
 hash_method = pbkdf2_sha256.encrypt
 
+def exatract_date(date_str):
+
+    date_object = datetime.strptime(date_str, '%m-%d-%y')
+    return date_object
+
+
+def exatract_time(datetime_str):
+
+    datetime_object = datetime.strptime(datetime_str, '%m-%d-%y %H:%M:%S')
+    return datetime_object
+
 
 def extract_columns_data(model: Gino.Model):
 
@@ -39,7 +52,10 @@ def extract_columns_data(model: Gino.Model):
         'VARCHAR': str,
         'FLOAT': float,
         'DECIMAL': float,
-        'NUMERIC': float
+        'NUMERIC': float,
+        'DATETIME': datetime,
+        'DATE':  datetime,
+        'BOOLEAN': bool
 
     }
     column_names = {}
@@ -124,9 +140,15 @@ async def admin_model_add_submit(request, model):
     try:
         for param in request_params:
             if '_hash' not in param and not isinstance(request_params[param], columns_data[param]):
-                request_params[param] = columns_data[param](request_params[param])
+                if columns_data[param] is not datetime:
+                    request_params[param] = columns_data[param](request_params[param])
+                else:
+                    # todo for date
+                    request_params[param] = exatract_time(request_params[param])
         await models[model].create(**request_params)
         request["flash"]("Object was added", "success")
+    except ValueError as e:
+        request["flash"](e.args, "error")
     except asyncpg.exceptions.ForeignKeyViolationError as e:
         request["flash"](e.args, "error")
     except asyncpg.exceptions.UniqueViolationError:
